import unittest
from mensajes.hola.saludos import generar_array

class Pruebashola(unittest.TestCase):
    def test_generar_array(self):
        np.testing.assert_array_equal(
            np.array([0, 1, 2, 3, 4, 5])
            generar_array(6)
        )



import numpy as np

def saludar():
    print("hola")

def generar_array(numeros):
	return np.arange(numeros)

def prueba():
    print("Esto es una prueba de la nueva versión")


class Saludo():

	def __init__(self):
		
		print("Hola, te estoy saludando desde el __init__ de la clase Saludo")




if __name__ == '__main__':
    print(generar_array(5))


from setuptools import setup, find_packages
setup(
    name = "Mensajes-keviruii",
    version = "3.0",
    description = "Un paquete para saludar y despedir",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author = "Kevin Ruiz",
    author_email = "kevinagustinrockz@gmail.com",
    url = "http://hcosta.info",
    license_files=['LICENSE'],
    packages=find_packages(),
    scripts = [],
    test_suite='tests',
    install_requires=[paquete.strip() for paquete in open('requirements.txt').readlines()],
    classifiers=[
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Topic :: Utilities'
    ]
)


